summaryrefslogtreecommitdiffstats
path: root/knetworkconf/knetworkconf/kaddressvalidator.h
diff options
context:
space:
mode:
Diffstat (limited to 'knetworkconf/knetworkconf/kaddressvalidator.h')
-rw-r--r--knetworkconf/knetworkconf/kaddressvalidator.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/knetworkconf/knetworkconf/kaddressvalidator.h b/knetworkconf/knetworkconf/kaddressvalidator.h
index 32dcc37..9e1df59 100644
--- a/knetworkconf/knetworkconf/kaddressvalidator.h
+++ b/knetworkconf/knetworkconf/kaddressvalidator.h
@@ -41,7 +41,7 @@
#include <sys/socket.h>
#include <arpa/inet.h>
#include <netinet/in.h>
-#include <qstring.h>
+#include <tqstring.h>
/**Class that has simple methods for validating IP addresses, netmasks, calculating
broadcast and network addresses.
@@ -54,20 +54,20 @@ public:
KAddressValidator();
~KAddressValidator();
/** Validates if the address written by the user is a valid one. Return true if it is and false if not. */
- static bool isValidIPAddress(QString addr);
+ static bool isValidIPAddress(TQString addr);
/** Validates if the Netmask written by the user is a valid one. Return true if it is and false if not. */
- static bool isNetmaskValid(QString addr);
+ static bool isNetmaskValid(TQString addr);
/** Validates if the Network written by the user is a valid one. Return true if it is and false if not. */
- static bool isNetworkValid(const QString &addr);
+ static bool isNetworkValid(const TQString &addr);
/** Validates if the Broadcast written by the user is a valid one. Return true if it is and false if not. */
- static bool isBroadcastValid(QString addr);
-
- /** Is a wrapper function to calc_network that receives the IP address and netsmask as QString and
- returns the network value also as a QString, or NULL if it couldn't be calculated. */
- static QString calculateNetwork(QString addr,QString netmask);
-/** Is a wrapper function to calc_broadcast that receives the IP address and netsmask as QString and
-returns the broadcast value also as a QString, or NULL if it couldn't be calculated. */
- static QString calculateBroadcast(QString addr, QString netmask);
+ static bool isBroadcastValid(TQString addr);
+
+ /** Is a wrapper function to calc_network that receives the IP address and netsmask as TQString and
+ returns the network value also as a TQString, or NULL if it couldn't be calculated. */
+ static TQString calculateNetwork(TQString addr,TQString netmask);
+/** Is a wrapper function to calc_broadcast that receives the IP address and netsmask as TQString and
+returns the broadcast value also as a TQString, or NULL if it couldn't be calculated. */
+ static TQString calculateBroadcast(TQString addr, TQString netmask);
private: // Private methods
/** \fn unsigned long int calc_broadcast(unsigned long int addr, int prefix)